==> mcmcr_0.0.2.tar.gz: mcmcr/R/bind-dimensions-n.R <==
#' Combine multiple MCMC objects by parameter dimensions
#'
#' Combines multiple MCMC objects (with the same parameters, chains and iterations) by parameter dimensions.
#'
#' @param ... one or more MCMC objects
#' @export
#' @seealso \code{\link{bind_dimensions}}
#' @examples
#' bind_dimensions_n(mcmcr_example, mcmcr_example, mcmcr_example)
bind_dimensions_n <- function(...) {
  UseMethod("bind_dimensions_n")
}

#' @describeIn bind_dimensions_n Binds multiple mcmcarray objects by their dimensions
#' @export
bind_dimensions_n.mcmcarray <- function(...) {
  x <- list(...)

  if(!length(x)) error("one or more objects must be passed to bind_dimensions_n")

  if(length(x) == 1) return(x[[1]])

  pdims <- lapply(x, pdims)
  if(!all(vapply(pdims, identical, TRUE, pdims[[1]])))
    error("all objects must have the same parameter dimensions")

  along <- pdims(x[[1]])
  along <- length(along) + 1L

  fun <- function(x1, x2) bind_dimensions(x1, x2, along = along)
  x <- Reduce(fun, x)
  x
}

#' @describeIn bind_dimensions_n Binds multiple mcmcr objects by their dimensions
#' @export
bind_dimensions_n.mcmcr <- function(...) {
  x <- list(...)

  if(!length(x)) error("one or more objects must be passed to bind_dimensions_n")

  if(length(x) == 1) return(x[[1]])

  pdims <- lapply(x, pdims)
  if(!all(vapply(pdims, identical, TRUE, pdims[[1]])))
    error("all objects must have the same parameter dimensions")

  along <- pdims(x[[1]])
  along <- vapply(along, length, 1L) + 1L

  fun <- function(x1, x2) bind_dimensions(x1, x2, along = along)
  x <- Reduce(fun, x)
  x
}

==> mcmcr_0.2.0.tar.gz: mcmcr/R/bind-dimensions-n.R <==
#' Combine multiple MCMC objects by parameter dimensions
#'
#' Combines multiple MCMC objects (with the same parameters, chains and iterations) by parameter dimensions.
#'
#' @param ... one or more MCMC objects
#' @export
#' @seealso \code{\link{bind_dimensions}}
#' @examples
#' bind_dimensions_n(mcmcr_example, mcmcr_example, mcmcr_example)
bind_dimensions_n <- function(...) {
  UseMethod("bind_dimensions_n")
}

#' @describeIn bind_dimensions_n Binds multiple mcmcarray objects by their dimensions
#' @export
bind_dimensions_n.mcmcarray <- function(...) {
  x <- list(...)

  if(!length(x)) err("one or more objects must be passed to bind_dimensions_n")

  if(length(x) == 1) return(x[[1]])

  pdims <- lapply(x, pdims)
  if(!all(vapply(pdims, identical, TRUE, pdims[[1]])))
    err("all objects must have the same parameter dimensions")

  along <- pdims(x[[1]])
  along <- length(along) + 1L

  fun <- function(x1, x2) bind_dimensions(x1, x2, along = along)
  x <- Reduce(fun, x)
  x
}

#' @describeIn bind_dimensions_n Binds multiple mcmcr objects by their dimensions
#' @export
bind_dimensions_n.mcmcr <- function(...) {
  x <- list(...)

  if(!length(x)) err("one or more objects must be passed to bind_dimensions_n")

  if(length(x) == 1) return(x[[1]])

  pdims <- lapply(x, pdims)
  if(!all(vapply(pdims, identical, TRUE, pdims[[1]])))
    err("all objects must have the same parameter dimensions")

  along <- pdims(x[[1]])
  along <- vapply(along, length, 1L) + 1L

  fun <- function(x1, x2) bind_dimensions(x1, x2, along = along)
  x <- Reduce(fun, x)
  x
}
